import React, { useRef } from 'react'
import { Row, Col, Space } from 'antd';
import { link, register } from '@/assets/images';
import { Form, Input, Button, Radio } from '@arco-design/web-react';
import ArcoUpload from '@/components/ArcoUpload';
import { Scrollbars } from "react-custom-scrollbars";

const RadioGroup = Radio.Group;
const FormItem = Form.Item;
const TextArea = Input.TextArea;

export default function Examine(props) {
  const formRef = useRef();
  const infoData = {
    reason: '已经与双方当事人沟通，其中被申请方反应所谓的“个性化学习计划”费用是得到了白云区教育局的批准，而该费用收取是否合理，本部门无法判断',
    file: '广东明智教育培训机构资质合理性调查记录.pdf',
    time: '2024-7-21 12:00',
    people: '白云区新市街市场监管所',
    person: '张晓霞',
  }

  const handleSubmit = () => {

  }

  return (
    <div className='dataSync'>
      <div className='dataSync-noBackTabPage'>
        <div className='whiteBox'>
          <Space size='small'>
            <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>回退申请</h5>
          </Space>
          <Row gutter={[16, 16]}>
            <Col span={24}>
              <div><div className="title-text">回退理由</div></div>
              <div>{infoData?.reason || '-'}</div>
            </Col>
            <Col span={24}>
              <div><div className="title-text">附件材料</div></div>
              <div style={{ color: '#1A6FB8' }}><img src={link} alt="" className="title-file" />{infoData?.file || '-'}</div>
            </Col>
            <Col span={24}>
              <div><div className="title-text">申请时间</div></div>
              <div>{infoData?.time || '-'}</div>
            </Col>
            <Col span={24}>
              <div><div className="title-text">申请人</div></div>
              <div>{infoData?.people}&nbsp;&nbsp;{infoData?.person}<img src={register} alt="" className="title-register" /></div>
            </Col>
          </Row>
        </div>
        <div className='whiteBox' style={{ marginTop: '8px' }}>
          <Scrollbars style={{ height: 'calc(100vh - 577px)' }} autoHide>
            <Space size='small'>
              <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>审核</h5>
            </Space>
            <Form
              ref={formRef}
              layout='vertical'
              requiredSymbol={false}
              initialValues={{
              }}//默认值
              scrollToFirstError
            >
              <Row>
                <Col span={24}>
                  <FormItem
                    label={(<div style={{ display: 'flex' }}>审核结果</div>)}
                    field='result'
                  >
                    <RadioGroup direction='vertical' options={[
                      {
                        label: '同意',
                        value: 1
                      },
                      {
                        label: '不同意',
                        value: 0
                      },
                    ]}>
                    </RadioGroup>
                  </FormItem>
                </Col>
                <Col span={24}>
                  <FormItem
                    label={(<div style={{ display: 'flex' }}>理由说明<div className="must">必填</div></div>)}
                    field='trueName'
                    rules={[{ required: true, message: '请选择理由说明' }]}
                  >
                    <RadioGroup direction='vertical' options={[
                      {
                        label: '回退理由不充分',
                        value: '0'
                      },
                      {
                        label: '回退延迟',
                        value: '1'
                      },
                      {
                        label: '其他',
                        value: '2'
                      },
                    ]}>
                    </RadioGroup>
                  </FormItem>
                </Col>
                <Col span={24}>
                  <FormItem
                    label=' '
                    field='luyou'
                    rules={[{ required: true, message: '理由不能为空' }]}
                  >
                    <TextArea
                      autoSize={{ minRows: 4, maxRows: 8 }}
                      placeholder='请填写回退的具体理由'
                    />
                  </FormItem>
                </Col>
                <Col span={24} className="doubleFile">
                  <ArcoUpload
                    params={{
                      action: ``,
                    }}
                    field='file'
                    label='附件材料'
                  />
                </Col>
              </Row>
            </Form>
          </Scrollbars>
          <div className='dialogFooter'>
            <Button
              type="primary"
              className="dialogPrimary"
              onClick={handleSubmit}
            >
              提交
            </Button>
          </div>
        </div>
      </div>
    </div>
  )
}
